[Pkg-cups-devel] r820 - in cupsys/trunk: . debian debian/local/filters/pdf-filters/filter

Martin Pitt mpitt at alioth.debian.org
Fri Aug 15 06:17:53 UTC 2008


Author: mpitt
Date: Fri Aug 15 06:17:53 2008
New Revision: 820

Log:
* debian/local/filters/pdf-filters/filter/texttopdf.c:
  - Use FreeMono instead of Courier, since texttopdf requires a TrueType
    font.

Modified:
   cupsys/trunk/   (props changed)
   cupsys/trunk/debian/changelog
   cupsys/trunk/debian/local/filters/pdf-filters/filter/texttopdf.c

Modified: cupsys/trunk/debian/changelog
==============================================================================
--- cupsys/trunk/debian/changelog	(original)
+++ cupsys/trunk/debian/changelog	Fri Aug 15 06:17:53 2008
@@ -31,6 +31,9 @@
     - Never create an outfile in the same directory as the given infile; the
       process might not have write access there.
     - set -e.
+  * debian/local/filters/pdf-filters/filter/texttopdf.c:
+    - Use FreeMono instead of Courier, since texttopdf requires a TrueType
+      font.
 
  -- Martin Pitt <mpitt at debian.org>  Thu, 14 Aug 2008 17:40:59 +0200
 

Modified: cupsys/trunk/debian/local/filters/pdf-filters/filter/texttopdf.c
==============================================================================
--- cupsys/trunk/debian/local/filters/pdf-filters/filter/texttopdf.c	(original)
+++ cupsys/trunk/debian/local/filters/pdf-filters/filter/texttopdf.c	Fri Aug 15 06:17:53 2008
@@ -737,16 +737,16 @@
   else // {{{ Standard ASCII
   {
    /*
     * Standard ASCII output just uses Courier, Courier-Bold, and
     * possibly Courier-Oblique.
     */
 
     NumFonts = 1;
 
-    Fonts[0][ATTR_NORMAL]     = font_load(datadir,"Courier");
-    Fonts[0][ATTR_BOLD]       = font_load(datadir,"Courier-Bold");
-    Fonts[0][ATTR_ITALIC]     = font_load(datadir,"Courier-Oblique");
-    Fonts[0][ATTR_BOLDITALIC] = font_load(datadir,"Courier-BoldOblique");
+    Fonts[0][ATTR_NORMAL]     = font_load(datadir,"FreeMono.ttf");
+    Fonts[0][ATTR_BOLD]       = font_load(datadir,"FreeMonoBold.ttf");
+    Fonts[0][ATTR_ITALIC]     = font_load(datadir,"FreeMonoOblique.ttf");
+    Fonts[0][ATTR_BOLDITALIC] = font_load(datadir,"FreeMonoBoldOblique.ttf");
 
     Widths[0]     = 1;
     Directions[0] = 1;
@@ -737,16 +737,16 @@
   {
    /*
-    * Standard ASCII output just uses Courier, Courier-Bold, and
-    * possibly Courier-Oblique.
+    * Standard ASCII output just uses FreeMono, FreeMono-Bold, and
+    * possibly FreeMono-Oblique.
     */
 



More information about the Pkg-cups-devel mailing list